
This site contains the latest documentation and guides for the
[Theta Data Python API](https://github.com/ThetaData-API/PythonAPI),
a Python package that provides low latency real-time & historical options data.

For more information, see [thetadata.net](https://thetadata.net).

## Development & Support

This project is open source and actively maintained on [Github](https://github.com/ThetaData-API/PythonAPI).
We've designed this API to be:

- Simple to use
- Performant
- Extensible

If you find we've compromised in any of these qualities,
please let us know by
[submitting an issue](https://github.com/ThetaData-API/PythonAPI/issues) or
dropping a message in the [Theta Data Discord](https://discord.gg/YXkxdc3h4T).
We value your feedback!

> **Tip:** Discovered a typo? Edit this page on [Github](https://github.com/ThetaData-API/PythonAPI/tree/master/docs)!

For larger problems, please email
[support@thetadata.net](mailto:support@thetadata.net) or call
[+1 (516)-898-3184](tel:15168983184). 
